
# Slot: prefix_prefix


the nsname (sans ':' for a given prefix)

URI: [linkml:prefix_prefix](https://w3id.org/linkml/prefix_prefix)


## Domain and Range

prefix &#8594;  <sub>1..1</sub> ncname

## Parents


## Children


## Used by

 * prefix
